Tinypng for pypicgo
===================

Tinypng for `PyPicGo <https://github.com/AnsGoo/PyPicGo>`__ to compress
images

install
-------

.. code:: shell

   pip install pypicgo-tinypng-plugin

config
------

.. code:: yaml

   tinypng:
     module: pypicgo_tinypng_plugin.TinypngPlugin
     config:
       key: xxxxxxxxxxxxxxx
